@@ -13,20 +13,22 @@
 #'   and number de actions (min-max) aggregated by a specific variable.
 #' @examples
 #' m1$PlotTimeonTaskbyVar(cp025q01.treated, "CP025Q01.TOT", "CP025Q01",
-#'                        namexlab = "Time on task (minutes)")
+#'   namexlab = "Time on task (minutes)"
+#' )
 #'
 PlotTimeonTaskbyVar <- function(data, tot.var, performance.item, namexlab,
                                 nameylab = "Density") {
+  data[[performance.item]] <- as.factor(data[[performance.item]])
 
-    data[[performance.item]] <- as.factor(data[[performance.item]])
-
-    ggplot2::ggplot(data, ggplot2::aes_string(x    = tot.var,
-                                              fill = performance.item)) +
-        ggplot2::theme_minimal() +
-        ggplot2::scale_fill_grey() +
-        ggplot2::geom_density(alpha = 0.5) +
-        ggplot2::xlab(namexlab) +
-        ggplot2::ylab(nameylab) +
-        ggplot2::xlim(0, 5) +
-        ggplot2::ylim(0, 1)
+  ggplot2::ggplot(data, ggplot2::aes_string(
+    x = tot.var,
+    fill = performance.item
+  )) +
+    ggplot2::theme_minimal() +
+    ggplot2::scale_fill_grey() +
+    ggplot2::geom_density(alpha = 0.5) +
+    ggplot2::xlab(namexlab) +
+    ggplot2::ylab(nameylab) +
+    ggplot2::xlim(0, 5) +
+    ggplot2::ylim(0, 1)
 }
